import { useRef, useEffect } from 'react';

var fallbackLog = function fallbackLog(v, label) {
  return console.log("%c Current  %c " + label + " ", "\n    color:white;\n    background-color:green; \n    border-radius:2px;\n    ", "\n    color:white;\n    background-color:blue; \n    border-radius:2px;\n    ", v);
};
var fallbackPrevLog = function fallbackPrevLog(v, label) {
  return console.log("%c Previous %c " + label + " ", "\n    color:white;\n    background-color:brown; \n    border-radius:2px;\n    ", "\n    color:white;\n    background-color:blue; \n    border-radius:2px;\n    ", v);
};
var isUseLoggerType = function isUseLoggerType(options) {
  return !!(options != null && options.loggerType);
};
var isUseLogger = function isUseLogger(options) {
  return !!(options != null && options.logger);
};
var isNil = function isNil(val) {
  return val === null || val === undefined;
};

/**
 *
 * @param state
 * @param options
 * @example
 * ```ts
 *  // when using `options.loggerType`, pass a string representing logging functions under `console`
 *  useLog(state,{
 *    loggerType:"table"
 *  })
 *  // when using `options.logger`,pass a `function` wrapping the native logging api
 *  useLog(state,{
 *    logger:(v:any)=>console.log("%c%s","color:red",v)
 *  })
 * ```
 */

var useLog = function useLog(state, label, options) {
  var prev = useRef();
  useEffect(function () {
    var logPreviousValue = isNil(options == null ? void 0 : options.logPreviousValue) ? true : options == null ? void 0 : options.logPreviousValue;
    var logger = isUseLoggerType(options) ? options.loggerType ? console[options.loggerType] : fallbackLog : isUseLogger(options) ? (options == null ? void 0 : options.logger) || fallbackLog : fallbackLog;
    var prevLogger = isUseLoggerType(options) ? options.previousStateLoggerType ? console[options.previousStateLoggerType] : fallbackPrevLog : isUseLogger(options) ? (options == null ? void 0 : options.logger) || fallbackPrevLog : fallbackPrevLog;
    var displayLabel = label || '';
    if (options != null && options.isGrouped) console.group(displayLabel);

    if (logPreviousValue) {
      prevLogger(prev.current, displayLabel);
    }

    logger(state, displayLabel);
    if (options != null && options.isGrouped) console.groupEnd();
    prev.current = state;
  }, [state, options, label]);
};

export { useLog };
//# sourceMappingURL=react-use-log.esm.js.map
